==> hs-xmonad-contrib-0.9.1p8.tgz: lib/ghc/xmonad-contrib-0.9.1/register.sh <==
#!/bin/sh
echo 'name: xmonad-contrib
version: 0.9.1
id: xmonad-contrib-0.9.1-e76851831b81b837e9073909356abad7

license: BSD3
copyright:
maintainer: spencerjanssen@gmail.com
stability:
homepage: http://xmonad.org/
package-url:
description: Third party tiling algorithms, configurations and scripts to xmonad,
             a tiling window manager for X.
             .
             For an introduction to building, configuring and using xmonad
             extensions, see "XMonad.Doc". In particular:
             .
             "XMonad.Doc.Configuring", a guide to configuring xmonad
             .
             "XMonad.Doc.Extending", using the contributed extensions library
             .
             "XMonad.Doc.Developing", introduction to xmonad internals and writing
             your own extensions.
category: System
author: Spencer Janssen
pkgpath: x11/hs-xmonad-contrib
exposed: True
exposed-modules: XMonad.Doc XMonad.Doc.Configuring
                 XMonad.Doc.Extending XMonad.Doc.Developing XMonad.Actions.Commands
                 XMonad.Actions.ConstrainedResize XMonad.Actions.CopyWindow
                 XMonad.Actions.CycleRecentWS XMonad.Actions.CycleSelectedLayouts
                 XMonad.Actions.CycleWindows XMonad.Actions.CycleWS
                 XMonad.Actions.DeManage XMonad.Actions.DwmPromote
                 XMonad.Actions.DynamicWorkspaces XMonad.Actions.FindEmptyWorkspace
                 XMonad.Actions.FlexibleManipulate XMonad.Actions.FlexibleResize
                 XMonad.Actions.FloatKeys XMonad.Actions.FloatSnap
                 XMonad.Actions.FocusNth XMonad.Actions.GridSelect
                 XMonad.Actions.MessageFeedback XMonad.Actions.MouseGestures
                 XMonad.Actions.MouseResize XMonad.Actions.NoBorders
                 XMonad.Actions.OnScreen XMonad.Actions.PerWorkspaceKeys
                 XMonad.Actions.PhysicalScreens XMonad.Actions.Plane
                 XMonad.Actions.Promote XMonad.Actions.RotSlaves
                 XMonad.Actions.RandomBackground XMonad.Actions.Search
                 XMonad.Actions.SimpleDate XMonad.Actions.SinkAll
                 XMonad.Actions.SpawnOn XMonad.Actions.Submap
                 XMonad.Actions.SwapWorkspaces XMonad.Actions.TagWindows
                 XMonad.Actions.TopicSpace XMonad.Actions.UpdatePointer
                 XMonad.Actions.UpdateFocus XMonad.Actions.Warp
                 XMonad.Actions.WindowMenu XMonad.Actions.WindowNavigation
                 XMonad.Actions.WindowGo XMonad.Actions.WindowBringer
                 XMonad.Actions.WithAll XMonad.Actions.WorkspaceCursors
                 XMonad.Config.Arossato XMonad.Config.Azerty XMonad.Config.Desktop
                 XMonad.Config.Droundy XMonad.Config.Gnome XMonad.Config.Kde
                 XMonad.Config.Sjanssen XMonad.Config.Xfce XMonad.Hooks.DynamicHooks
                 XMonad.Hooks.DynamicLog XMonad.Hooks.EwmhDesktops
                 XMonad.Hooks.FadeInactive XMonad.Hooks.FloatNext
                 XMonad.Hooks.InsertPosition XMonad.Hooks.ManageDocks
                 XMonad.Hooks.ManageHelpers XMonad.Hooks.Place
                 XMonad.Hooks.RestoreMinimized XMonad.Hooks.Script
                 XMonad.Hooks.SetWMName XMonad.Hooks.ServerMode
                 XMonad.Hooks.UrgencyHook XMonad.Hooks.WorkspaceByPos
                 XMonad.Hooks.XPropManage XMonad.Layout.Accordion
                 XMonad.Layout.AutoMaster XMonad.Layout.BorderResize
                 XMonad.Layout.BoringWindows XMonad.Layout.CenteredMaster
                 XMonad.Layout.Circle XMonad.Layout.Cross XMonad.Layout.Column
                 XMonad.Layout.Combo XMonad.Layout.ComboP XMonad.Layout.Decoration
                 XMonad.Layout.DecorationMadness XMonad.Layout.Dishes
                 XMonad.Layout.DragPane XMonad.Layout.DwmStyle
                 XMonad.Layout.FixedColumn XMonad.Layout.Gaps XMonad.Layout.Grid
                 XMonad.Layout.GridVariants XMonad.Layout.HintedGrid
                 XMonad.Layout.HintedTile XMonad.Layout.IM
                 XMonad.Layout.IndependentScreens XMonad.Layout.LayoutBuilder
                 XMonad.Layout.LayoutCombinators XMonad.Layout.LayoutHints
                 XMonad.Layout.LayoutModifier XMonad.Layout.LayoutScreens
                 XMonad.Layout.LimitWindows XMonad.Layout.MagicFocus
                 XMonad.Layout.Magnifier XMonad.Layout.Master XMonad.Layout.Maximize
                 XMonad.Layout.MessageControl XMonad.Layout.Minimize
                 XMonad.Layout.Monitor XMonad.Layout.Mosaic XMonad.Layout.MosaicAlt
                 XMonad.Layout.MouseResizableTile XMonad.Layout.MultiToggle
                 XMonad.Layout.MultiToggle.Instances XMonad.Layout.Named
                 XMonad.Layout.NoBorders XMonad.Layout.NoFrillsDecoration
                 XMonad.Layout.OneBig XMonad.Layout.PerWorkspace
                 XMonad.Layout.Reflect XMonad.Layout.ResizableTile
                 XMonad.Layout.ResizeScreen XMonad.Layout.Roledex
                 XMonad.Layout.Simplest XMonad.Layout.SimpleDecoration
                 XMonad.Layout.SimpleFloat XMonad.Layout.Spacing
                 XMonad.Layout.Spiral XMonad.Layout.Square XMonad.Layout.ShowWName
                 XMonad.Layout.StackTile XMonad.Layout.SubLayouts
                 XMonad.Layout.Tabbed XMonad.Layout.TabBarDecoration
                 XMonad.Layout.ThreeColumns XMonad.Layout.ToggleLayouts
                 XMonad.Layout.TwoPane XMonad.Layout.WindowArranger
                 XMonad.Layout.WindowNavigation XMonad.Layout.WorkspaceDir
                 XMonad.Layout.SimplestFloat XMonad.Prompt.Directory XMonad.Prompt
                 XMonad.Prompt.AppendFile XMonad.Prompt.AppLauncher
                 XMonad.Prompt.Input XMonad.Prompt.Email XMonad.Prompt.Layout
                 XMonad.Prompt.Man XMonad.Prompt.DirExec XMonad.Prompt.RunOrRaise
                 XMonad.Prompt.Shell XMonad.Prompt.Ssh XMonad.Prompt.Theme
                 XMonad.Prompt.Window XMonad.Prompt.Workspace XMonad.Prompt.XMonad
                 XMonad.Util.Cursor XMonad.Util.CustomKeys XMonad.Util.Dmenu
                 XMonad.Util.Dzen XMonad.Util.EZConfig XMonad.Util.Font
                 XMonad.Util.Invisible XMonad.Util.Loggers XMonad.Util.NamedActions
                 XMonad.Util.NamedScratchpad XMonad.Util.NamedWindows
                 XMonad.Util.StringProp XMonad.Util.Run XMonad.Util.Scratchpad
                 XMonad.Util.Themes XMonad.Util.Timer XMonad.Util.Types
                 XMonad.Util.WindowProperties XMonad.Util.WorkspaceCompare
                 XMonad.Util.Paste XMonad.Util.Replace XMonad.Util.XSelection
                 XMonad.Util.XUtils
hidden-modules:
import-dirs: /usr/local/lib/ghc/xmonad-contrib-0.9.1
library-dirs: /usr/local/lib/ghc/xmonad-contrib-0.9.1
hs-libraries: HSxmonad-contrib-0.9.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: X11-1.5.0.0-e303e9e71d3b6055d5c970517461f343
         base-3.0.3.2-33c49b5f57a891ca80151e2f4f33f82c
         containers-0.3.0.0-7be04792060ce1514c52e2cb13a5c18a
         directory-1.0.1.1-7962558b34e6144244ddec948ea3bb41
         mtl-1.1.0.2-9e35d291e0ab20c6aa18823de23bc2de
         old-locale-1.0.0.2-0c1a4b40f2d3b9f6b725f54c00fe0923
         old-time-1.0.0.5-56dd504e1de073228be3dcc82225ab48
         process-1.0.1.3-9d7ee2878f05261df44c8ba16836d6e6
         random-1.0.0.2-a4bf29bbfd08ec91d43a4c919e9253f8
         unix-2.4.0.2-e19c58dff4d7270211af62a28c7c17f9
         utf8-string-0.3.6-5ee26357cb5966310fb19966a1a80ed8
         xmonad-0.9.1-0d4e2d652cd66c3944084957726f1542
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-xmonad-contrib-0.9.1/html/xmonad-contrib.haddock
haddock-html: /usr/local/share/doc/hs-xmonad-contrib-0.9.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-xmonad-contrib-0.9.2p2.tgz: lib/ghc/xmonad-contrib-0.9.2/register.sh <==
#!/bin/sh
echo 'name: xmonad-contrib
version: 0.9.2
id: xmonad-contrib-0.9.2-6dc2ae3f2243a7b404b4ce1ef50bef82

license: BSD3
copyright:
maintainer: spencerjanssen@gmail.com
stability:
homepage: http://xmonad.org/
package-url:
description: Third party tiling algorithms, configurations and scripts to xmonad,
             a tiling window manager for X.
             .
             For an introduction to building, configuring and using xmonad
             extensions, see "XMonad.Doc". In particular:
             .
             "XMonad.Doc.Configuring", a guide to configuring xmonad
             .
             "XMonad.Doc.Extending", using the contributed extensions library
             .
             "XMonad.Doc.Developing", introduction to xmonad internals and writing
             your own extensions.
category: System
author: Spencer Janssen
pkgpath: x11/hs-xmonad-contrib
exposed: True
exposed-modules: XMonad.Doc XMonad.Doc.Configuring
                 XMonad.Doc.Extending XMonad.Doc.Developing XMonad.Actions.Commands
                 XMonad.Actions.ConstrainedResize XMonad.Actions.CopyWindow
                 XMonad.Actions.CycleRecentWS XMonad.Actions.CycleSelectedLayouts
                 XMonad.Actions.CycleWindows XMonad.Actions.CycleWS
                 XMonad.Actions.DeManage XMonad.Actions.DwmPromote
                 XMonad.Actions.DynamicWorkspaces XMonad.Actions.FindEmptyWorkspace
                 XMonad.Actions.FlexibleManipulate XMonad.Actions.FlexibleResize
                 XMonad.Actions.FloatKeys XMonad.Actions.FloatSnap
                 XMonad.Actions.FocusNth XMonad.Actions.GridSelect
                 XMonad.Actions.MessageFeedback XMonad.Actions.MouseGestures
                 XMonad.Actions.MouseResize XMonad.Actions.NoBorders
                 XMonad.Actions.OnScreen XMonad.Actions.PerWorkspaceKeys
                 XMonad.Actions.PhysicalScreens XMonad.Actions.Plane
                 XMonad.Actions.Promote XMonad.Actions.RotSlaves
                 XMonad.Actions.RandomBackground XMonad.Actions.Search
                 XMonad.Actions.SimpleDate XMonad.Actions.SinkAll
                 XMonad.Actions.SpawnOn XMonad.Actions.Submap
                 XMonad.Actions.SwapWorkspaces XMonad.Actions.TagWindows
                 XMonad.Actions.TopicSpace XMonad.Actions.UpdatePointer
                 XMonad.Actions.UpdateFocus XMonad.Actions.Warp
                 XMonad.Actions.WindowMenu XMonad.Actions.WindowNavigation
                 XMonad.Actions.WindowGo XMonad.Actions.WindowBringer
                 XMonad.Actions.WithAll XMonad.Actions.WorkspaceCursors
                 XMonad.Config.Arossato XMonad.Config.Azerty XMonad.Config.Desktop
                 XMonad.Config.Droundy XMonad.Config.Gnome XMonad.Config.Kde
                 XMonad.Config.Sjanssen XMonad.Config.Xfce XMonad.Hooks.DynamicHooks
                 XMonad.Hooks.DynamicLog XMonad.Hooks.EwmhDesktops
                 XMonad.Hooks.FadeInactive XMonad.Hooks.FloatNext
                 XMonad.Hooks.InsertPosition XMonad.Hooks.ManageDocks
                 XMonad.Hooks.ManageHelpers XMonad.Hooks.Place
                 XMonad.Hooks.RestoreMinimized XMonad.Hooks.Script
                 XMonad.Hooks.SetWMName XMonad.Hooks.ServerMode
                 XMonad.Hooks.UrgencyHook XMonad.Hooks.WorkspaceByPos
                 XMonad.Hooks.XPropManage XMonad.Layout.Accordion
                 XMonad.Layout.AutoMaster XMonad.Layout.BorderResize
                 XMonad.Layout.BoringWindows XMonad.Layout.CenteredMaster
                 XMonad.Layout.Circle XMonad.Layout.Cross XMonad.Layout.Column
                 XMonad.Layout.Combo XMonad.Layout.ComboP XMonad.Layout.Decoration
                 XMonad.Layout.DecorationMadness XMonad.Layout.Dishes
                 XMonad.Layout.DragPane XMonad.Layout.DwmStyle
                 XMonad.Layout.FixedColumn XMonad.Layout.Gaps XMonad.Layout.Grid
                 XMonad.Layout.GridVariants XMonad.Layout.HintedGrid
                 XMonad.Layout.HintedTile XMonad.Layout.IM
                 XMonad.Layout.IndependentScreens XMonad.Layout.LayoutBuilder
                 XMonad.Layout.LayoutCombinators XMonad.Layout.LayoutHints
                 XMonad.Layout.LayoutModifier XMonad.Layout.LayoutScreens
                 XMonad.Layout.LimitWindows XMonad.Layout.MagicFocus
                 XMonad.Layout.Magnifier XMonad.Layout.Master XMonad.Layout.Maximize
                 XMonad.Layout.MessageControl XMonad.Layout.Minimize
                 XMonad.Layout.Monitor XMonad.Layout.Mosaic XMonad.Layout.MosaicAlt
                 XMonad.Layout.MouseResizableTile XMonad.Layout.MultiToggle
                 XMonad.Layout.MultiToggle.Instances XMonad.Layout.Named
                 XMonad.Layout.NoBorders XMonad.Layout.NoFrillsDecoration
                 XMonad.Layout.OneBig XMonad.Layout.PerWorkspace
                 XMonad.Layout.Reflect XMonad.Layout.ResizableTile
                 XMonad.Layout.ResizeScreen XMonad.Layout.Roledex
                 XMonad.Layout.Simplest XMonad.Layout.SimpleDecoration
                 XMonad.Layout.SimpleFloat XMonad.Layout.Spacing
                 XMonad.Layout.Spiral XMonad.Layout.Square XMonad.Layout.ShowWName
                 XMonad.Layout.StackTile XMonad.Layout.SubLayouts
                 XMonad.Layout.Tabbed XMonad.Layout.TabBarDecoration
                 XMonad.Layout.ThreeColumns XMonad.Layout.ToggleLayouts
                 XMonad.Layout.TwoPane XMonad.Layout.WindowArranger
                 XMonad.Layout.WindowNavigation XMonad.Layout.WorkspaceDir
                 XMonad.Layout.SimplestFloat XMonad.Prompt.Directory XMonad.Prompt
                 XMonad.Prompt.AppendFile XMonad.Prompt.AppLauncher
                 XMonad.Prompt.Input XMonad.Prompt.Email XMonad.Prompt.Layout
                 XMonad.Prompt.Man XMonad.Prompt.DirExec XMonad.Prompt.RunOrRaise
                 XMonad.Prompt.Shell XMonad.Prompt.Ssh XMonad.Prompt.Theme
                 XMonad.Prompt.Window XMonad.Prompt.Workspace XMonad.Prompt.XMonad
                 XMonad.Util.Cursor XMonad.Util.CustomKeys XMonad.Util.Dmenu
                 XMonad.Util.Dzen XMonad.Util.EZConfig XMonad.Util.Font
                 XMonad.Util.Invisible XMonad.Util.Loggers XMonad.Util.NamedActions
                 XMonad.Util.NamedScratchpad XMonad.Util.NamedWindows
                 XMonad.Util.StringProp XMonad.Util.Run XMonad.Util.Scratchpad
                 XMonad.Util.Themes XMonad.Util.Timer XMonad.Util.Types
                 XMonad.Util.WindowProperties XMonad.Util.WorkspaceCompare
                 XMonad.Util.Paste XMonad.Util.Replace XMonad.Util.XSelection
                 XMonad.Util.XUtils
hidden-modules:
import-dirs: /usr/local/lib/ghc/xmonad-contrib-0.9.2
library-dirs: /usr/local/lib/ghc/xmonad-contrib-0.9.2
hs-libraries: HSxmonad-contrib-0.9.2
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: X11-1.5.0.0-36d317925f45deb13d15f41314b23680
         X11-xft-0.3-d88c668cd0816066c8caf56fffe7e0d8
         base-4.3.1.0-e1ba2d2213b66179f3e0c901a27d3a96
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
         directory-1.1.0.0-9315160d2d0511510edc9d31fb968f3c
         extensible-exceptions-0.1.1.2-d8c5b906654260efd7249f497d17a831
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
         old-locale-1.0.0.2-cc522edd16b73a70b897598c5f5d20c7
         old-time-1.0.0.6-dfdb9c34ec39bc9a2a57345b38e135d4
         process-1.0.1.5-55dfaccf3a91c4cb8f6284a0bafef198
         random-1.0.0.3-15ae8b1458485ee9647f74174e442c33
         unix-2.4.2.0-090cf1b1ab645511a5a62d8d94ee4eb7
         utf8-string-0.3.6-a224390ae58ffa205a5f11c5e75af14f
         xmonad-0.9.2-cf18bf074930804b3d2397579ea50a3c
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-xmonad-contrib-0.9.2/html/xmonad-contrib.haddock
haddock-html: /usr/local/share/doc/hs-xmonad-contrib-0.9.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
